pub struct CreateComputeNodeGroupFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateComputeNodeGroup.
Creates a managed set of compute nodes. You associate a compute node group with a cluster through 1 or more PCS queues or as part of the login fleet. A compute node group includes the definition of the compute properties and lifecycle management. PCS uses the information you provide to this API action to launch compute nodes in your account. You can only specify subnets in the same Amazon VPC as your cluster. You receive billing charges for the compute nodes that PCS launches in your account. You must already have a launch template before you call this API. For more information, see Launch an instance from a launch template in the Amazon Elastic Compute Cloud User Guide for Linux Instances.
Implementations
Sourceimpl CreateComputeNodeGroupFluentBuilder
impl CreateComputeNodeGroupFluentBuilder
Sourcepub fn as_input(&self) -> &CreateComputeNodeGroupInputBuilder
pub fn as_input(&self) -> &CreateComputeNodeGroupInputBuilder
Access the CreateComputeNodeGroup as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateComputeNodeGroupOutput, SdkError<CreateComputeNodeGroupError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateComputeNodeGroupOutput, SdkError<CreateComputeNodeGroupError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateComputeNodeGroupOutput, CreateComputeNodeGroupError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateComputeNodeGroupOutput, CreateComputeNodeGroupError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn cluster_identifier(self, input: impl Into<String>) -> Self
pub fn cluster_identifier(self, input: impl Into<String>) -> Self
The name or ID of the cluster to create a compute node group in.
Sourcepub fn set_cluster_identifier(self, input: Option<String>) -> Self
pub fn set_cluster_identifier(self, input: Option<String>) -> Self
The name or ID of the cluster to create a compute node group in.
Sourcepub fn get_cluster_identifier(&self) -> &Option<String>
pub fn get_cluster_identifier(&self) -> &Option<String>
The name or ID of the cluster to create a compute node group in.
Sourcepub fn compute_node_group_name(self, input: impl Into<String>) -> Self
pub fn compute_node_group_name(self, input: impl Into<String>) -> Self
A name to identify the cluster. Example: MyCluster
Sourcepub fn set_compute_node_group_name(self, input: Option<String>) -> Self
pub fn set_compute_node_group_name(self, input: Option<String>) -> Self
A name to identify the cluster. Example: MyCluster
Sourcepub fn get_compute_node_group_name(&self) -> &Option<String>
pub fn get_compute_node_group_name(&self) -> &Option<String>
A name to identify the cluster. Example: MyCluster
Sourcepub fn ami_id(self, input: impl Into<String>) -> Self
pub fn ami_id(self, input: impl Into<String>) -> Self
The ID of the Amazon Machine Image (AMI) that PCS uses to launch compute nodes (Amazon EC2 instances). If you don't provide this value, PCS uses the AMI ID specified in the custom launch template.
Sourcepub fn set_ami_id(self, input: Option<String>) -> Self
pub fn set_ami_id(self, input: Option<String>) -> Self
The ID of the Amazon Machine Image (AMI) that PCS uses to launch compute nodes (Amazon EC2 instances). If you don't provide this value, PCS uses the AMI ID specified in the custom launch template.
Sourcepub fn get_ami_id(&self) -> &Option<String>
pub fn get_ami_id(&self) -> &Option<String>
The ID of the Amazon Machine Image (AMI) that PCS uses to launch compute nodes (Amazon EC2 instances). If you don't provide this value, PCS uses the AMI ID specified in the custom launch template.
Sourcepub fn subnet_ids(self, input: impl Into<String>) -> Self
pub fn subnet_ids(self, input: impl Into<String>) -> Self
Appends an item to subnetIds.
To override the contents of this collection use set_subnet_ids.
The list of subnet IDs where the compute node group launches instances. Subnets must be in the same VPC as the cluster.
Sourcepub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
The list of subnet IDs where the compute node group launches instances. Subnets must be in the same VPC as the cluster.
Sourcepub fn get_subnet_ids(&self) -> &Option<Vec<String>>
pub fn get_subnet_ids(&self) -> &Option<Vec<String>>
The list of subnet IDs where the compute node group launches instances. Subnets must be in the same VPC as the cluster.
Sourcepub fn purchase_option(self, input: PurchaseOption) -> Self
pub fn purchase_option(self, input: PurchaseOption) -> Self
Specifies how EC2 instances are purchased on your behalf. PCS supports On-Demand Instances, Spot Instances, Interruptible Capacity Reservations, On-Demand Capacity Reservations, and Amazon EC2 Capacity Blocks for ML. For more information, see Amazon EC2 billing and purchasing options in the Amazon Elastic Compute Cloud User Guide. For more information about PCS support for Capacity Blocks, see Using Amazon EC2 Capacity Blocks for ML with PCS in the PCS User Guide. For more information about PCS support for interruptible capacity reservations, see Using I-ODCRs with PCS in the PCS User Guide. Choose On-Demand if you plan to use an On-Demand Capacity Reservation (ODCR). For more information, see Using ODCRs with PCS. If you don't provide this option, it defaults to On-Demand.
Sourcepub fn set_purchase_option(self, input: Option<PurchaseOption>) -> Self
pub fn set_purchase_option(self, input: Option<PurchaseOption>) -> Self
Specifies how EC2 instances are purchased on your behalf. PCS supports On-Demand Instances, Spot Instances, Interruptible Capacity Reservations, On-Demand Capacity Reservations, and Amazon EC2 Capacity Blocks for ML. For more information, see Amazon EC2 billing and purchasing options in the Amazon Elastic Compute Cloud User Guide. For more information about PCS support for Capacity Blocks, see Using Amazon EC2 Capacity Blocks for ML with PCS in the PCS User Guide. For more information about PCS support for interruptible capacity reservations, see Using I-ODCRs with PCS in the PCS User Guide. Choose On-Demand if you plan to use an On-Demand Capacity Reservation (ODCR). For more information, see Using ODCRs with PCS. If you don't provide this option, it defaults to On-Demand.
Sourcepub fn get_purchase_option(&self) -> &Option<PurchaseOption>
pub fn get_purchase_option(&self) -> &Option<PurchaseOption>
Specifies how EC2 instances are purchased on your behalf. PCS supports On-Demand Instances, Spot Instances, Interruptible Capacity Reservations, On-Demand Capacity Reservations, and Amazon EC2 Capacity Blocks for ML. For more information, see Amazon EC2 billing and purchasing options in the Amazon Elastic Compute Cloud User Guide. For more information about PCS support for Capacity Blocks, see Using Amazon EC2 Capacity Blocks for ML with PCS in the PCS User Guide. For more information about PCS support for interruptible capacity reservations, see Using I-ODCRs with PCS in the PCS User Guide. Choose On-Demand if you plan to use an On-Demand Capacity Reservation (ODCR). For more information, see Using ODCRs with PCS. If you don't provide this option, it defaults to On-Demand.
Sourcepub fn custom_launch_template(self, input: CustomLaunchTemplate) -> Self
pub fn custom_launch_template(self, input: CustomLaunchTemplate) -> Self
An Amazon EC2 launch template PCS uses to launch compute nodes.
Sourcepub fn set_custom_launch_template(
self,
input: Option<CustomLaunchTemplate>,
) -> Self
pub fn set_custom_launch_template( self, input: Option<CustomLaunchTemplate>, ) -> Self
An Amazon EC2 launch template PCS uses to launch compute nodes.
Sourcepub fn get_custom_launch_template(&self) -> &Option<CustomLaunchTemplate>
pub fn get_custom_launch_template(&self) -> &Option<CustomLaunchTemplate>
An Amazon EC2 launch template PCS uses to launch compute nodes.
Sourcepub fn iam_instance_profile_arn(self, input: impl Into<String>) -> Self
pub fn iam_instance_profile_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the IAM instance profile used to pass an IAM role when launching EC2 instances. The role contained in your instance profile must have the pcs:RegisterComputeNodeGroupInstance permission and the role name must start with AWSPCS or must have the path /aws-pcs/. For more information, see IAM instance profiles for PCS in the PCS User Guide.
Sourcepub fn set_iam_instance_profile_arn(self, input: Option<String>) -> Self
pub fn set_iam_instance_profile_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the IAM instance profile used to pass an IAM role when launching EC2 instances. The role contained in your instance profile must have the pcs:RegisterComputeNodeGroupInstance permission and the role name must start with AWSPCS or must have the path /aws-pcs/. For more information, see IAM instance profiles for PCS in the PCS User Guide.
Sourcepub fn get_iam_instance_profile_arn(&self) -> &Option<String>
pub fn get_iam_instance_profile_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the IAM instance profile used to pass an IAM role when launching EC2 instances. The role contained in your instance profile must have the pcs:RegisterComputeNodeGroupInstance permission and the role name must start with AWSPCS or must have the path /aws-pcs/. For more information, see IAM instance profiles for PCS in the PCS User Guide.
Sourcepub fn scaling_configuration(self, input: ScalingConfigurationRequest) -> Self
pub fn scaling_configuration(self, input: ScalingConfigurationRequest) -> Self
Specifies the boundaries of the compute node group auto scaling.
Sourcepub fn set_scaling_configuration(
self,
input: Option<ScalingConfigurationRequest>,
) -> Self
pub fn set_scaling_configuration( self, input: Option<ScalingConfigurationRequest>, ) -> Self
Specifies the boundaries of the compute node group auto scaling.
Sourcepub fn get_scaling_configuration(&self) -> &Option<ScalingConfigurationRequest>
pub fn get_scaling_configuration(&self) -> &Option<ScalingConfigurationRequest>
Specifies the boundaries of the compute node group auto scaling.
Sourcepub fn instance_configs(self, input: InstanceConfig) -> Self
pub fn instance_configs(self, input: InstanceConfig) -> Self
Appends an item to instanceConfigs.
To override the contents of this collection use set_instance_configs.
A list of EC2 instance configurations that PCS can provision in the compute node group.
Sourcepub fn set_instance_configs(self, input: Option<Vec<InstanceConfig>>) -> Self
pub fn set_instance_configs(self, input: Option<Vec<InstanceConfig>>) -> Self
A list of EC2 instance configurations that PCS can provision in the compute node group.
Sourcepub fn get_instance_configs(&self) -> &Option<Vec<InstanceConfig>>
pub fn get_instance_configs(&self) -> &Option<Vec<InstanceConfig>>
A list of EC2 instance configurations that PCS can provision in the compute node group.
Sourcepub fn spot_options(self, input: SpotOptions) -> Self
pub fn spot_options(self, input: SpotOptions) -> Self
Additional configuration when you specify SPOT as the purchaseOption for the CreateComputeNodeGroup API action.
Sourcepub fn set_spot_options(self, input: Option<SpotOptions>) -> Self
pub fn set_spot_options(self, input: Option<SpotOptions>) -> Self
Additional configuration when you specify SPOT as the purchaseOption for the CreateComputeNodeGroup API action.
Sourcepub fn get_spot_options(&self) -> &Option<SpotOptions>
pub fn get_spot_options(&self) -> &Option<SpotOptions>
Additional configuration when you specify SPOT as the purchaseOption for the CreateComputeNodeGroup API action.
Sourcepub fn slurm_configuration(
self,
input: ComputeNodeGroupSlurmConfigurationRequest,
) -> Self
pub fn slurm_configuration( self, input: ComputeNodeGroupSlurmConfigurationRequest, ) -> Self
Additional options related to the Slurm scheduler.
Sourcepub fn set_slurm_configuration(
self,
input: Option<ComputeNodeGroupSlurmConfigurationRequest>,
) -> Self
pub fn set_slurm_configuration( self, input: Option<ComputeNodeGroupSlurmConfigurationRequest>, ) -> Self
Additional options related to the Slurm scheduler.
Sourcepub fn get_slurm_configuration(
&self,
) -> &Option<ComputeNodeGroupSlurmConfigurationRequest>
pub fn get_slurm_configuration( &self, ) -> &Option<ComputeNodeGroupSlurmConfigurationRequest>
Additional options related to the Slurm scheduler.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
1 or more tags added to the resource. Each tag consists of a tag key and tag value. The tag value is optional and can be an empty string.
1 or more tags added to the resource. Each tag consists of a tag key and tag value. The tag value is optional and can be an empty string.
1 or more tags added to the resource. Each tag consists of a tag key and tag value. The tag value is optional and can be an empty string.