#[non_exhaustive]pub struct CreateComputeNodeGroupInput {Show 13 fields
pub cluster_identifier: Option<String>,
pub compute_node_group_name: Option<String>,
pub ami_id: Option<String>,
pub subnet_ids: Option<Vec<String>>,
pub purchase_option: Option<PurchaseOption>,
pub custom_launch_template: Option<CustomLaunchTemplate>,
pub iam_instance_profile_arn: Option<String>,
pub scaling_configuration: Option<ScalingConfigurationRequest>,
pub instance_configs: Option<Vec<InstanceConfig>>,
pub spot_options: Option<SpotOptions>,
pub slurm_configuration: Option<ComputeNodeGroupSlurmConfigurationRequest>,
pub client_token: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_identifier: Option<String>The name or ID of the cluster to create a compute node group in.
compute_node_group_name: Option<String>A name to identify the cluster. Example: MyCluster
ami_id: Option<String>The ID of the Amazon Machine Image (AMI) that PCS uses to launch compute nodes (Amazon EC2 instances). If you don't provide this value, PCS uses the AMI ID specified in the custom launch template.
subnet_ids: Option<Vec<String>>The list of subnet IDs where the compute node group launches instances. Subnets must be in the same VPC as the cluster.
purchase_option: Option<PurchaseOption>Specifies how EC2 instances are purchased on your behalf. PCS supports On-Demand Instances, Spot Instances, and Amazon EC2 Capacity Blocks for ML. For more information, see Amazon EC2 billing and purchasing options in the Amazon Elastic Compute Cloud User Guide. For more information about PCS support for Capacity Blocks, see Using Amazon EC2 Capacity Blocks for ML with PCS in the PCS User Guide. If you don't provide this option, it defaults to On-Demand.
custom_launch_template: Option<CustomLaunchTemplate>An Amazon EC2 launch template PCS uses to launch compute nodes.
iam_instance_profile_arn: Option<String>The Amazon Resource Name (ARN) of the IAM instance profile used to pass an IAM role when launching EC2 instances. The role contained in your instance profile must have the pcs:RegisterComputeNodeGroupInstance permission and the role name must start with AWSPCS or must have the path /aws-pcs/. For more information, see IAM instance profiles for PCS in the PCS User Guide.
scaling_configuration: Option<ScalingConfigurationRequest>Specifies the boundaries of the compute node group auto scaling.
instance_configs: Option<Vec<InstanceConfig>>A list of EC2 instance configurations that PCS can provision in the compute node group.
spot_options: Option<SpotOptions>Additional configuration when you specify SPOT as the purchaseOption for the CreateComputeNodeGroup API action.
slurm_configuration: Option<ComputeNodeGroupSlurmConfigurationRequest>Additional options related to the Slurm scheduler.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.
1 or more tags added to the resource. Each tag consists of a tag key and tag value. The tag value is optional and can be an empty string.
Implementations
Sourceimpl CreateComputeNodeGroupInput
impl CreateComputeNodeGroupInput
Sourcepub fn cluster_identifier(&self) -> Option<&str>
pub fn cluster_identifier(&self) -> Option<&str>
The name or ID of the cluster to create a compute node group in.
Sourcepub fn compute_node_group_name(&self) -> Option<&str>
pub fn compute_node_group_name(&self) -> Option<&str>
A name to identify the cluster. Example: MyCluster
Sourcepub fn ami_id(&self) -> Option<&str>
pub fn ami_id(&self) -> Option<&str>
The ID of the Amazon Machine Image (AMI) that PCS uses to launch compute nodes (Amazon EC2 instances). If you don't provide this value, PCS uses the AMI ID specified in the custom launch template.
Sourcepub fn subnet_ids(&self) -> &[String]
pub fn subnet_ids(&self) -> &[String]
The list of subnet IDs where the compute node group launches instances. Subnets must be in the same VPC as the cluster.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .subnet_ids.is_none().
Sourcepub fn purchase_option(&self) -> Option<&PurchaseOption>
pub fn purchase_option(&self) -> Option<&PurchaseOption>
Specifies how EC2 instances are purchased on your behalf. PCS supports On-Demand Instances, Spot Instances, and Amazon EC2 Capacity Blocks for ML. For more information, see Amazon EC2 billing and purchasing options in the Amazon Elastic Compute Cloud User Guide. For more information about PCS support for Capacity Blocks, see Using Amazon EC2 Capacity Blocks for ML with PCS in the PCS User Guide. If you don't provide this option, it defaults to On-Demand.
Sourcepub fn custom_launch_template(&self) -> Option<&CustomLaunchTemplate>
pub fn custom_launch_template(&self) -> Option<&CustomLaunchTemplate>
An Amazon EC2 launch template PCS uses to launch compute nodes.
Sourcepub fn iam_instance_profile_arn(&self) -> Option<&str>
pub fn iam_instance_profile_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the IAM instance profile used to pass an IAM role when launching EC2 instances. The role contained in your instance profile must have the pcs:RegisterComputeNodeGroupInstance permission and the role name must start with AWSPCS or must have the path /aws-pcs/. For more information, see IAM instance profiles for PCS in the PCS User Guide.
Sourcepub fn scaling_configuration(&self) -> Option<&ScalingConfigurationRequest>
pub fn scaling_configuration(&self) -> Option<&ScalingConfigurationRequest>
Specifies the boundaries of the compute node group auto scaling.
Sourcepub fn instance_configs(&self) -> &[InstanceConfig]
pub fn instance_configs(&self) -> &[InstanceConfig]
A list of EC2 instance configurations that PCS can provision in the compute node group.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .instance_configs.is_none().
Sourcepub fn spot_options(&self) -> Option<&SpotOptions>
pub fn spot_options(&self) -> Option<&SpotOptions>
Additional configuration when you specify SPOT as the purchaseOption for the CreateComputeNodeGroup API action.
Sourcepub fn slurm_configuration(
&self,
) -> Option<&ComputeNodeGroupSlurmConfigurationRequest>
pub fn slurm_configuration( &self, ) -> Option<&ComputeNodeGroupSlurmConfigurationRequest>
Additional options related to the Slurm scheduler.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.
1 or more tags added to the resource. Each tag consists of a tag key and tag value. The tag value is optional and can be an empty string.
Sourceimpl CreateComputeNodeGroupInput
impl CreateComputeNodeGroupInput
Sourcepub fn builder() -> CreateComputeNodeGroupInputBuilder
pub fn builder() -> CreateComputeNodeGroupInputBuilder
Creates a new builder-style object to manufacture CreateComputeNodeGroupInput.