#[non_exhaustive]pub struct DeleteComputeNodeGroupInput {
pub cluster_identifier: Option<String>,
pub compute_node_group_identifier: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_identifier: Option<String>The name or ID of the cluster of the compute node group.
compute_node_group_identifier: Option<String>The name or ID of the compute node group to delete.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.
Implementations
Sourceimpl DeleteComputeNodeGroupInput
impl DeleteComputeNodeGroupInput
Sourcepub fn cluster_identifier(&self) -> Option<&str>
pub fn cluster_identifier(&self) -> Option<&str>
The name or ID of the cluster of the compute node group.
Sourcepub fn compute_node_group_identifier(&self) -> Option<&str>
pub fn compute_node_group_identifier(&self) -> Option<&str>
The name or ID of the compute node group to delete.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect. If you don't specify a client token, the CLI and SDK automatically generate 1 for you.
Sourceimpl DeleteComputeNodeGroupInput
impl DeleteComputeNodeGroupInput
Sourcepub fn builder() -> DeleteComputeNodeGroupInputBuilder
pub fn builder() -> DeleteComputeNodeGroupInputBuilder
Creates a new builder-style object to manufacture DeleteComputeNodeGroupInput.