#[non_exhaustive]pub struct ListComputeNodeGroupsInputBuilder { /* private fields */ }Expand description
A builder for ListComputeNodeGroupsInput.
Implementations
Sourceimpl ListComputeNodeGroupsInputBuilder
impl ListComputeNodeGroupsInputBuilder
Sourcepub fn cluster_identifier(self, input: impl Into<String>) -> Self
pub fn cluster_identifier(self, input: impl Into<String>) -> Self
The name or ID of the cluster to list compute node groups for.
This field is required.Sourcepub fn set_cluster_identifier(self, input: Option<String>) -> Self
pub fn set_cluster_identifier(self, input: Option<String>) -> Self
The name or ID of the cluster to list compute node groups for.
Sourcepub fn get_cluster_identifier(&self) -> &Option<String>
pub fn get_cluster_identifier(&self) -> &Option<String>
The name or ID of the cluster to list compute node groups for.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The value of nextToken is a unique pagination token for each page of results returned. If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token returns an HTTP 400 InvalidToken error.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The value of nextToken is a unique pagination token for each page of results returned. If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token returns an HTTP 400 InvalidToken error.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
The value of nextToken is a unique pagination token for each page of results returned. If nextToken is returned, there are more results available. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token returns an HTTP 400 InvalidToken error.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results that are returned per call. You can use nextToken to obtain further pages of results. The default is 10 results, and the maximum allowed page size is 100 results. A value of 0 uses the default.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results that are returned per call. You can use nextToken to obtain further pages of results. The default is 10 results, and the maximum allowed page size is 100 results. A value of 0 uses the default.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results that are returned per call. You can use nextToken to obtain further pages of results. The default is 10 results, and the maximum allowed page size is 100 results. A value of 0 uses the default.
Sourcepub fn build(self) -> Result<ListComputeNodeGroupsInput, BuildError>
pub fn build(self) -> Result<ListComputeNodeGroupsInput, BuildError>
Consumes the builder and constructs a ListComputeNodeGroupsInput.
Sourceimpl ListComputeNodeGroupsInputBuilder
impl ListComputeNodeGroupsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListComputeNodeGroupsOutput, SdkError<ListComputeNodeGroupsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListComputeNodeGroupsOutput, SdkError<ListComputeNodeGroupsError, HttpResponse>>
Sends a request with this input using the given client.