#[non_exhaustive]pub struct RegisterComputeNodeGroupInstanceOutputBuilder { /* private fields */ }Expand description
A builder for RegisterComputeNodeGroupInstanceOutput.
Implementations
Sourceimpl RegisterComputeNodeGroupInstanceOutputBuilder
impl RegisterComputeNodeGroupInstanceOutputBuilder
Sourcepub fn node_id(self, input: impl Into<String>) -> Self
pub fn node_id(self, input: impl Into<String>) -> Self
The scheduler node ID for this instance.
This field is required.Sourcepub fn set_node_id(self, input: Option<String>) -> Self
pub fn set_node_id(self, input: Option<String>) -> Self
The scheduler node ID for this instance.
Sourcepub fn get_node_id(&self) -> &Option<String>
pub fn get_node_id(&self) -> &Option<String>
The scheduler node ID for this instance.
For the Slurm scheduler, this is the shared Munge key the scheduler uses to authenticate compute node group instances.
This field is required.For the Slurm scheduler, this is the shared Munge key the scheduler uses to authenticate compute node group instances.
For the Slurm scheduler, this is the shared Munge key the scheduler uses to authenticate compute node group instances.
Sourcepub fn endpoints(self, input: Endpoint) -> Self
pub fn endpoints(self, input: Endpoint) -> Self
Appends an item to endpoints.
To override the contents of this collection use set_endpoints.
The list of endpoints available for interaction with the scheduler.
Sourcepub fn set_endpoints(self, input: Option<Vec<Endpoint>>) -> Self
pub fn set_endpoints(self, input: Option<Vec<Endpoint>>) -> Self
The list of endpoints available for interaction with the scheduler.
Sourcepub fn get_endpoints(&self) -> &Option<Vec<Endpoint>>
pub fn get_endpoints(&self) -> &Option<Vec<Endpoint>>
The list of endpoints available for interaction with the scheduler.
Sourcepub fn build(self) -> Result<RegisterComputeNodeGroupInstanceOutput, BuildError>
pub fn build(self) -> Result<RegisterComputeNodeGroupInstanceOutput, BuildError>
Consumes the builder and constructs a RegisterComputeNodeGroupInstanceOutput.
This method will fail if any of the following fields are not set: