#[non_exhaustive]pub struct RegisterComputeNodeGroupInstanceInput {
pub cluster_identifier: Option<String>,
pub bootstrap_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_identifier: Option<String>The name or ID of the cluster to register the compute node group instance in.
bootstrap_id: Option<String>The client-generated token to allow for retries.
Implementations
Sourceimpl RegisterComputeNodeGroupInstanceInput
impl RegisterComputeNodeGroupInstanceInput
Sourcepub fn cluster_identifier(&self) -> Option<&str>
pub fn cluster_identifier(&self) -> Option<&str>
The name or ID of the cluster to register the compute node group instance in.
Sourcepub fn bootstrap_id(&self) -> Option<&str>
pub fn bootstrap_id(&self) -> Option<&str>
The client-generated token to allow for retries.
Sourceimpl RegisterComputeNodeGroupInstanceInput
impl RegisterComputeNodeGroupInstanceInput
Sourcepub fn builder() -> RegisterComputeNodeGroupInstanceInputBuilder
pub fn builder() -> RegisterComputeNodeGroupInstanceInputBuilder
Creates a new builder-style object to manufacture RegisterComputeNodeGroupInstanceInput.