#[non_exhaustive]pub struct QueueSummaryBuilder { /* private fields */ }Expand description
A builder for QueueSummary.
Implementations
Sourceimpl QueueSummaryBuilder
impl QueueSummaryBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name that identifies the queue.
This field is required.Sourcepub fn id(self, input: impl Into<String>) -> Self
pub fn id(self, input: impl Into<String>) -> Self
The generated unique ID of the queue.
This field is required.Sourcepub fn arn(self, input: impl Into<String>) -> Self
pub fn arn(self, input: impl Into<String>) -> Self
The unique Amazon Resource Name (ARN) of the queue.
This field is required.Sourcepub fn set_arn(self, input: Option<String>) -> Self
pub fn set_arn(self, input: Option<String>) -> Self
The unique Amazon Resource Name (ARN) of the queue.
Sourcepub fn cluster_id(self, input: impl Into<String>) -> Self
pub fn cluster_id(self, input: impl Into<String>) -> Self
The ID of the cluster of the queue.
This field is required.Sourcepub fn set_cluster_id(self, input: Option<String>) -> Self
pub fn set_cluster_id(self, input: Option<String>) -> Self
The ID of the cluster of the queue.
Sourcepub fn get_cluster_id(&self) -> &Option<String>
pub fn get_cluster_id(&self) -> &Option<String>
The ID of the cluster of the queue.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time the resource was created.
This field is required.Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time the resource was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time the resource was created.
Sourcepub fn modified_at(self, input: DateTime) -> Self
pub fn modified_at(self, input: DateTime) -> Self
The date and time the resource was modified.
This field is required.Sourcepub fn set_modified_at(self, input: Option<DateTime>) -> Self
pub fn set_modified_at(self, input: Option<DateTime>) -> Self
The date and time the resource was modified.
Sourcepub fn get_modified_at(&self) -> &Option<DateTime>
pub fn get_modified_at(&self) -> &Option<DateTime>
The date and time the resource was modified.
Sourcepub fn status(self, input: QueueStatus) -> Self
pub fn status(self, input: QueueStatus) -> Self
The provisioning status of the queue.
The provisioning status doesn't indicate the overall health of the queue.
The resource enters the SUSPENDING and SUSPENDED states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can't use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is SUSPENDED. For more information, see Frequently asked questions about Slurm versions in PCS in the PCS User Guide.
Sourcepub fn set_status(self, input: Option<QueueStatus>) -> Self
pub fn set_status(self, input: Option<QueueStatus>) -> Self
The provisioning status of the queue.
The provisioning status doesn't indicate the overall health of the queue.
The resource enters the SUSPENDING and SUSPENDED states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can't use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is SUSPENDED. For more information, see Frequently asked questions about Slurm versions in PCS in the PCS User Guide.
Sourcepub fn get_status(&self) -> &Option<QueueStatus>
pub fn get_status(&self) -> &Option<QueueStatus>
The provisioning status of the queue.
The provisioning status doesn't indicate the overall health of the queue.
The resource enters the SUSPENDING and SUSPENDED states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can't use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is SUSPENDED. For more information, see Frequently asked questions about Slurm versions in PCS in the PCS User Guide.
Sourcepub fn build(self) -> Result<QueueSummary, BuildError>
pub fn build(self) -> Result<QueueSummary, BuildError>
Consumes the builder and constructs a QueueSummary.
This method will fail if any of the following fields are not set: