#[non_exhaustive]pub struct ClusterSummary {
pub name: String,
pub id: String,
pub arn: String,
pub created_at: DateTime,
pub modified_at: DateTime,
pub status: ClusterStatus,
}Expand description
The object returned by the ListClusters API action.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name that identifies the cluster.
id: StringThe generated unique ID of the cluster.
arn: StringThe unique Amazon Resource Name (ARN) of the cluster.
created_at: DateTimeThe date and time the resource was created.
modified_at: DateTimeThe date and time the resource was modified.
status: ClusterStatusThe provisioning status of the cluster.
The provisioning status doesn't indicate the overall health of the cluster.
The resource enters the SUSPENDING and SUSPENDED states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can't use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is SUSPENDED. For more information, see Frequently asked questions about Slurm versions in PCS in the PCS User Guide.
Implementations
Sourceimpl ClusterSummary
impl ClusterSummary
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The date and time the resource was created.
Sourcepub fn modified_at(&self) -> &DateTime
pub fn modified_at(&self) -> &DateTime
The date and time the resource was modified.
Sourcepub fn status(&self) -> &ClusterStatus
pub fn status(&self) -> &ClusterStatus
The provisioning status of the cluster.
The provisioning status doesn't indicate the overall health of the cluster.
The resource enters the SUSPENDING and SUSPENDED states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can't use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is SUSPENDED. For more information, see Frequently asked questions about Slurm versions in PCS in the PCS User Guide.
Sourceimpl ClusterSummary
impl ClusterSummary
Sourcepub fn builder() -> ClusterSummaryBuilder
pub fn builder() -> ClusterSummaryBuilder
Creates a new builder-style object to manufacture ClusterSummary.