#[non_exhaustive]pub struct ComputeNodeGroupSummary {
pub name: String,
pub id: String,
pub arn: String,
pub cluster_id: String,
pub created_at: DateTime,
pub modified_at: DateTime,
pub status: ComputeNodeGroupStatus,
}Expand description
The object returned by the ListComputeNodeGroups API action.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name that identifies the compute node group.
id: StringThe generated unique ID of the compute node group.
arn: StringThe unique Amazon Resource Name (ARN) of the compute node group.
cluster_id: StringThe ID of the cluster of the compute node group.
created_at: DateTimeThe date and time the resource was created.
modified_at: DateTimeThe date and time the resource was modified.
status: ComputeNodeGroupStatusThe provisioning status of the compute node group.
The provisioning status doesn't indicate the overall health of the compute node group.
The resource enters the SUSPENDING and SUSPENDED states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can't use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is SUSPENDED. For more information, see Frequently asked questions about Slurm versions in PCS in the PCS User Guide.
Implementations
Sourceimpl ComputeNodeGroupSummary
impl ComputeNodeGroupSummary
Sourcepub fn cluster_id(&self) -> &str
pub fn cluster_id(&self) -> &str
The ID of the cluster of the compute node group.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The date and time the resource was created.
Sourcepub fn modified_at(&self) -> &DateTime
pub fn modified_at(&self) -> &DateTime
The date and time the resource was modified.
Sourcepub fn status(&self) -> &ComputeNodeGroupStatus
pub fn status(&self) -> &ComputeNodeGroupStatus
The provisioning status of the compute node group.
The provisioning status doesn't indicate the overall health of the compute node group.
The resource enters the SUSPENDING and SUSPENDED states when the scheduler is beyond end of life and we have suspended the cluster. When in these states, you can't use the cluster. The cluster controller is down and all compute instances are terminated. The resources still count toward your service quotas. You can delete a resource if its status is SUSPENDED. For more information, see Frequently asked questions about Slurm versions in PCS in the PCS User Guide.
Sourceimpl ComputeNodeGroupSummary
impl ComputeNodeGroupSummary
Sourcepub fn builder() -> ComputeNodeGroupSummaryBuilder
pub fn builder() -> ComputeNodeGroupSummaryBuilder
Creates a new builder-style object to manufacture ComputeNodeGroupSummary.