#[non_exhaustive]pub struct NodeLifecycleActions {
pub stages: Option<NodeLifecycleStages>,
pub script_caching_policy: ScriptCachingPolicy,
}Expand description
The lifecycle actions configured on a compute node group. Lifecycle actions define scripts that PCS runs on compute nodes at specific stages of their lifecycle.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stages: Option<NodeLifecycleStages>The lifecycle stages where you configure scripts to run.
script_caching_policy: ScriptCachingPolicyThe caching policy for node lifecycle scripts. The default value is CACHE_ONCE. Valid values:
-
CACHE_ONCE– Downloads each script once and reuses it on subsequent boots. -
REFRESH_ON_REBOOT– Downloads each script on every boot.
Implementations
Sourceimpl NodeLifecycleActions
impl NodeLifecycleActions
Sourcepub fn stages(&self) -> Option<&NodeLifecycleStages>
pub fn stages(&self) -> Option<&NodeLifecycleStages>
The lifecycle stages where you configure scripts to run.
Sourcepub fn script_caching_policy(&self) -> &ScriptCachingPolicy
pub fn script_caching_policy(&self) -> &ScriptCachingPolicy
The caching policy for node lifecycle scripts. The default value is CACHE_ONCE. Valid values:
-
CACHE_ONCE– Downloads each script once and reuses it on subsequent boots. -
REFRESH_ON_REBOOT– Downloads each script on every boot.
Sourceimpl NodeLifecycleActions
impl NodeLifecycleActions
Sourcepub fn builder() -> NodeLifecycleActionsBuilder
pub fn builder() -> NodeLifecycleActionsBuilder
Creates a new builder-style object to manufacture NodeLifecycleActions.